'use strict'

const argx = require('argx')
const co = require('co')
const SrchLogger = require('./logging/srch_logger')

const types = require('./types.json')
const matchAnyProp = require('./matching/match_any_prop')
const searchType = require('./searching/search_type')

/** @lends apemanSrch */
function apemanSrch (terms, options) {
  let args = argx(arguments)
  options = args.pop('object') || {}
  terms = args.remain()

  let typeName = options.type
  let logger = new SrchLogger({})

  return co(function * () {
    let invalid = typeName && !types[ typeName ]
    if (invalid) {
      throw new Error('Unknown type: ' + typeName)
    }
    logger.logSearchStart()
    let found = []
    if (typeName) {
      found.push(
        yield searchType(types[ typeName ])
      )
    } else {
      for (let typeName of Object.keys(types)) {
        found.push(
          yield searchType(types[ typeName ])
        )
      }
    }
    logger.logSearchDone()
    found = [].concat(found || [])
      .filter((found) => !!found)
      .filter((found) => {
        if (terms.length === 0) {
          found.hit = true
          return found
        }
        for (let i = 0, len = terms.length; i < len; i++) {
          let term = terms[ i ]
          let hit = matchAnyProp(found, term)
          if (hit) {
            found.hit = true
            found.hitTerm = term
            return found
          }
        }
        found.hit = false
        return found
      })
    logger.logSearched(found, terms)
    return found
  })
}

module.exports = apemanSrch
