/**
 * List repository for an organization.
 * @function listOrgRepo
 * @param {string} name - Name of organization.
 * @param {function} callback - Callback when done.
 * @returns {Promise}
 */

'use strict'

const _apiRequest = require('./_api_request')
const argx = require('argx')
const co = require('co')
const Promise = require('apemanpromise')

const MAX_PER_PAGE = 100
const MAX_PAGE = 5

/** @lends listOrgRepo */
function listOrgRepo (name, options) {
  let args = argx(arguments)
  options = args.pop('object') || {}
  let page = 1
  let found = []

  return co(function * () {
    let hasNext = () => {
      return (found.length <= (MAX_PER_PAGE * (page - 1)))
    }
    while (hasNext()) {
      let pathname = `/orgs/${name}/repos?per_page=${MAX_PER_PAGE}&page=${page}`
      let body = yield _apiRequest(pathname)
      let data = JSON.parse(body).map(listOrgRepo.parse)
      found = found.concat(data)
      page = yield new Promise(resolve =>
        setTimeout(() => {
          resolve(page + 1)
        }, 200 + (100 * Math.random()))
      )
      if (page > MAX_PAGE) {
        break
      }
    }
  })
}

listOrgRepo.parse = function parse (data) {
  return {
    name: data.name,
    full_name: data.full_name,
    private: data.private,
    description: data.description,
    url: data.url,
    fork: data.fork
  }
}

module.exports = listOrgRepo
