/**
 * Test case for apemanSrch.
 * Runs with mocha.
 */
'use strict'

const https = require('https'),
    injectmock = require('injectmock'),
    assert = require('assert')

let apemanSrch = require('../lib/apeman_srch.js')

describe('apeman-srch', () => {

    it('Run command.', (done) => {
        injectmock(https, 'get', function (config, callback) {
            let data = [
                {
                    name: 'apeman-task-mkdir',
                    full_name: 'apeman-task-labo/apeman-task-mkdir',
                    private: false,
                    description: 'apeman task to generate directories.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-mkdir',
                    fork: false
                },
                {
                    name: 'apeman-task-chmod',
                    full_name: 'apeman-task-labo/apeman-task-chmod',
                    private: false,
                    description: 'apeman task to change file permissions',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-chmod',
                    fork: false
                },
                {
                    name: 'apeman-task-coz',
                    full_name: 'apeman-task-labo/apeman-task-coz',
                    private: false,
                    description: 'apeman task to render coz bud files.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-coz',
                    fork: false
                },
                {
                    name: 'apeman-task-copy',
                    full_name: 'apeman-task-labo/apeman-task-copy',
                    private: false,
                    description: 'apeman task to copy files.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-copy',
                    fork: false
                },
                {
                    name: 'apeman-task-concat',
                    full_name: 'apeman-task-labo/apeman-task-concat',
                    private: false,
                    description: 'apeman task to concat files.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-concat',
                    fork: false
                },
                {
                    name: 'apeman-task-mocha',
                    full_name: 'apeman-task-labo/apeman-task-mocha',
                    private: false,
                    description: 'apeman task to run mocha.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-mocha',
                    fork: false
                },
                {
                    name: 'apeman-task-mocha',
                    full_name: 'apeman-task-labo/apeman-task-mocha',
                    private: false,
                    description: 'apeman task to run mocha.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-mocha',
                    fork: false
                },
                {
                    name: 'apeman-task-karma',
                    full_name: 'apeman-task-labo/apeman-task-karma',
                    private: false,
                    description: 'apeman task to run karma.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-karma',
                    fork: false
                },
                {
                    name: 'apeman-task-jade',
                    full_name: 'apeman-task-labo/apeman-task-jade',
                    private: false,
                    description: 'apeman task to compile jade files.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-jade',
                    fork: false
                },
                {
                    name: 'apeman-task-symlink',
                    full_name: 'apeman-task-labo/apeman-task-symlink',
                    private: false,
                    description: 'apeman task to create symlink.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-symlink',
                    fork: false
                },
                {
                    name: 'apeman-task-task',
                    full_name: 'apeman-task-labo/apeman-task-task',
                    private: false,
                    description: 'apeman task to run other apeman tasks.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-task',
                    fork: false
                },
                {
                    name: 'apeman-task-execcli',
                    full_name: 'apeman-task-labo/apeman-task-execcli',
                    private: false,
                    description: 'apeman task to execute cli command.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-execcli',
                    fork: false
                },
                {
                    name: 'apeman-task-scss',
                    full_name: 'apeman-task-labo/apeman-task-scss',
                    private: false,
                    description: 'apeman task to compile sass.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-scss',
                    fork: false
                },
                {
                    name: 'apeman-task-versionup',
                    full_name: 'apeman-task-labo/apeman-task-versionup',
                    private: false,
                    description: 'apeman task to increment package version.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-versionup',
                    fork: false
                },
                {
                    name: 'apeman-task-taggit',
                    full_name: 'apeman-task-labo/apeman-task-taggit',
                    private: false,
                    description: 'apeman task to create git tag.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-taggit',
                    fork: false
                },
                {
                    name: 'apeman-task-jsdoc',
                    full_name: 'apeman-task-labo/apeman-task-jsdoc',
                    private: false,
                    description: 'apeman task to generate jsdoc.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-jsdoc',
                    fork: false
                },
                {
                    name: 'apeman-task-coverage',
                    full_name: 'apeman-task-labo/apeman-task-coverage',
                    private: false,
                    description: 'apeman task to measure coverage.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-coverage',
                    fork: false
                },
                {
                    name: 'apeman-task-fmtjson',
                    full_name: 'apeman-task-labo/apeman-task-fmtjson',
                    private: false,
                    description: 'apeman task to format json files.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-fmtjson',
                    fork: false
                },
                {
                    name: 'apeman-task-apiguide',
                    full_name: 'apeman-task-labo/apeman-task-apiguide',
                    private: false,
                    description: 'apeman task to generate apiguide',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-apiguide',
                    fork: false
                },
                {
                    name: 'apeman-task-bower',
                    full_name: 'apeman-task-labo/apeman-task-bower',
                    private: false,
                    description: 'apeman task to install bower components.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-bower',
                    fork: false
                },
                {
                    name: 'apeman-task-update',
                    full_name: 'apeman-task-labo/apeman-task-update',
                    private: false,
                    description: 'apeman task to update package dependencies.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-update',
                    fork: false
                },
                {
                    name: 'apeman-task-sure',
                    full_name: 'apeman-task-labo/apeman-task-sure',
                    private: false,
                    description: 'apeman task to ask sure',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-sure',
                    fork: false
                },
                {
                    name: 'apeman-task-push',
                    full_name: 'apeman-task-labo/apeman-task-push',
                    private: false,
                    description: 'apeman task to push git.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-push',
                    fork: false
                },
                {
                    name: 'apeman-task-publish',
                    full_name: 'apeman-task-labo/apeman-task-publish',
                    private: false,
                    description: 'apeman task to publish npm package.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-publish',
                    fork: false
                },
                {
                    name: 'apeman-task-install',
                    full_name: 'apeman-task-labo/apeman-task-install',
                    private: false,
                    description: 'apeman task to install npm packages.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-install',
                    fork: false
                },
                {
                    name: 'apeman-task-tmpl',
                    full_name: 'apeman-task-labo/apeman-task-tmpl',
                    private: false,
                    description: 'apeman task to run apeman tmpl command.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-tmpl',
                    fork: false
                },
                {
                    name: 'apeman-task-codeclimate',
                    full_name: 'apeman-task-labo/apeman-task-codeclimate',
                    private: false,
                    description: 'apeman task to send test report to codeclimate.com',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-codeclimate',
                    fork: false
                },
                {
                    name: 'apeman-task-clean',
                    full_name: 'apeman-task-labo/apeman-task-clean',
                    private: false,
                    description: 'apeman task to delete files.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-clean',
                    fork: false
                },
                {
                    name: 'apeman-task-jsx',
                    full_name: 'apeman-task-labo/apeman-task-jsx',
                    private: false,
                    description: 'apeman task to compile jsx files.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-jsx',
                    fork: false
                },
                {
                    name: 'apeman-task-browserify',
                    full_name: 'apeman-task-labo/apeman-task-browserify',
                    private: false,
                    description: 'apeman task to run browserify.',
                    url: 'https://api.github.com/repos/apeman-task-labo/apeman-task-browserify',
                    fork: false
                }
            ];
            while(data.length < 20){
                data.push({})
            }
            let content = JSON.stringify(data)
            let res = {
                on(ev, callback) {
                    switch (ev) {
                        case 'data':
                            setTimeout(() => {
                                callback(content)
                            }, 5)
                            break;
                        case 'end':
                            setTimeout(() => {
                                callback(null)
                            }, 20)
                            break;
                    }
                },
                statusCode: 200
            }
            callback(res)
        })
        apemanSrch("pu", {type: 'task'}).then(
            () => done(),
            err => {
                assert.ifError(err)
                done()
            }
        )
    })
})

/* global describe, before, after, it */
